@@ -25,7 +25,6 @@ use super::{
 use anyhow::Result;
 
 use ratatui::{
-    backend::Backend,
     layout::{Constraint, Direction, Layout},
     style::Color,
     Frame,
@@ -50,6 +49,7 @@ pub const ACTIVE_CONTROL_COLOR: Color = Color::Reset;
 pub const INACTIVE_CONTROL_COLOR: Color = Color::Rgb(170, 170, 200);
 pub const EDITOR_MODE_COLOR: Color = Color::LightGreen;
 pub const INVALID_CONTROL_COLOR: Color = Color::LightRed;
+pub const VISUAL_MODE_COLOR: Color = Color::Blue;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum ControlType {
@@ -117,10 +117,9 @@ impl<'a, 'b> UIComponents<'a> {
         self.editor.set_current_entry(entry_id, app);
     }
 
-    pub fn render_ui<D, B>(&mut self, f: &mut Frame<B>, app: &'b App<D>)
+    pub fn render_ui<D>(&mut self, f: &mut Frame, app: &'b App<D>)
     where
         D: DataProvider,
-        B: Backend,
     {
         let chunks = Layout::default()
             .direction(Direction::Vertical)
@@ -141,10 +140,7 @@ impl<'a, 'b> UIComponents<'a> {
         self.render_popup(f);
     }
 
-    pub fn render_popup<B>(&mut self, f: &mut Frame<B>)
-    where
-        B: Backend,
-    {
+    pub fn render_popup(&mut self, f: &mut Frame) {
         if let Some(popup) = self.popup_stack.last_mut() {
             match popup {
                 Popup::Help(help_popup) => help_popup.render_widget(f, f.size()),
@@ -166,11 +162,17 @@ impl<'a, 'b> UIComponents<'a> {
             return self.handle_popup_input(input, app).await;
         }
 
-        if self.editor.is_insert_mode() {
+        if self.editor.is_prioritized() {
             if let Some(key) = self.editor_keymaps.iter().find(|c| &c.key == input) {
-                return key.command.clone().execute(self, app).await;
+                let command_result = key.command.clone().execute(self, app).await?;
+                if matches!(command_result, HandleInputReturnType::Handled) {
+                    return Ok(command_result);
+                }
+            }
+            let handle_result = self.editor.handle_input_prioritized(input, app)?;
+            if matches!(handle_result, HandleInputReturnType::Handled) {
+                return Ok(handle_result);
             }
-            return self.editor.handle_input(input, app);
         }
 
         if self.entries_list.multi_select_mode {
@@ -350,7 +352,7 @@ impl<'a, 'b> UIComponents<'a> {
         self.change_active_control(ControlType::EntryContentTxt);
 
         assert!(!self.editor.is_insert_mode());
-        self.editor.mode = EditorMode::Insert;
+        self.editor.set_editor_mode(EditorMode::Insert);
         Ok(HandleInputReturnType::Handled)
     }
 
